package com.example.dialogy;

import java.util.Arrays;

import android.app.AlertDialog;
import android.app.Dialog;
import android.content.DialogInterface;
import android.os.Bundle;
import android.support.v4.app.DialogFragment;
import android.support.v4.app.FragmentActivity;
import android.support.v4.app.FragmentTransaction;
import android.util.Log;
import android.view.View;
import android.widget.Toast;

import com.example.dialogy.DialogsListFragment.OnDialogsListItemClickListener;

public class DialogyActivity extends FragmentActivity implements
		OnDialogsListItemClickListener {

	private static final String KEY_SHOW_TOASTS = "showToasts";
	private static final String MODERN_ALERT_DIALOG = "modernAlertDialog";
	private static final String SAMPLE_DIALOG_FRAGMENT = "sampleDialogFragment";
	private static final int SIMPLE_DIALOG = 0;
	
	private boolean showToasts = true;
	private boolean dualPane;

	
	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);

		if (savedInstanceState != null && savedInstanceState.containsKey(KEY_SHOW_TOASTS)) {
			showToasts = savedInstanceState.getBoolean(KEY_SHOW_TOASTS);
			Log.d("keys", Arrays.toString(savedInstanceState.keySet().toArray(new String[0])));
		}

		setContentView(R.layout.main);
		
		FragmentTransaction ft = getSupportFragmentManager().beginTransaction();
		ft.add(R.id.left_column, new DialogsListFragment());
		ft.commit();
		
		showToast("onCreate");

		dualPane = findViewById(R.id.right_column) != null;
	}
	
	@Override
	protected void onRestart() {
		super.onRestart();
		showToast("onRestart");
	}
	@Override
	protected void onStart() {
		super.onStart();
		showToast("onStart");
	}
	@Override
	protected void onResume() {
		super.onResume();
		showToast("onResume");
	}
	@Override
	protected void onPause() {
		super.onPause();
		showToast("onPause");
	}
	@Override
	protected void onStop() {
		super.onStop();
		showToast("onStop");
	}
	@Override
	protected void onDestroy() {
		super.onDestroy();
		showToast("onDestroy");
	}
	
	@Override
	protected void onSaveInstanceState(Bundle outState) {
		outState.putBoolean(KEY_SHOW_TOASTS, showToasts);

		super.onSaveInstanceState(outState);

		showToast("onSaveInstanceState");
	}
	
	@Override
	protected void onRestoreInstanceState(Bundle savedInstanceState){
		super.onRestoreInstanceState(savedInstanceState);
		showToast("onRestoreInstanceState");
	}

	public void toggleToasts(View v) {
		showToasts = !showToasts;
	}

	private void showToast(String text) {
		if (showToasts) {
			Toast.makeText(this, text, Toast.LENGTH_SHORT).show();
		}
		Log.d("DialogyActivity", text);
	}

	public void onClick(int dialog) {
		switch (dialog) {
		case DialogsListFragment.OUTDATED_ALERT_DIALOG:
			showDialog(SIMPLE_DIALOG);
			break;
		case DialogsListFragment.MODERN_ALERT_DIALOG:
			showModernAlertDialog();
			break;
		case DialogsListFragment.SAMPLE_DIALOG_FRAGMENT:
			showSampleDialogFragment();
			break;
		}
	}

	protected Dialog onCreateDialog(int id) {
		switch (id) {
		case SIMPLE_DIALOG:
			return new AlertDialog.Builder(this)
					.setMessage(R.string.alert_dialog_basic_message)
					.setTitle(R.string.alert_dialog_basic_title)
					.setCancelable(false)
					.setPositiveButton(R.string.switchoff,
							new DialogInterface.OnClickListener() {
								public void onClick(DialogInterface dialog,
										int id) {
									DialogyActivity.this.finish();
								}
							})
					.setNeutralButton(R.string.maybe,
							new DialogInterface.OnClickListener() {
								public void onClick(DialogInterface dialog,
										int id) {
									if (Math.random() > 0.5) {
										DialogyActivity.this.finish();
									} else {
										dialog.cancel();
									}
								}
							})
					.setNegativeButton(R.string.no,
							new DialogInterface.OnClickListener() {
								public void onClick(DialogInterface dialog,
										int id) {
									dialog.cancel();
								}
							}).create();

		default:
			return null;
		}
	}
	
	private void showModernAlertDialog(){
		new ModernAlertDialogFragment().show(getSupportFragmentManager(), MODERN_ALERT_DIALOG);
	}

	/*
	 * Při změně orientace zůstane zobrazený SampleDialogFragment jako dialog,
	 * i když je displej landscape. A naopak, v paměti zůstane SampleDialogFragment
	 * jako fragment, i když je displej portrait. Dalo by se to dát dopořádku,
	 * ale vyžadovalo by to existující SampleDialogFragment zničit a vytvořit nový.
	 * To je pro naši ukázku zbytečná komplikace navíc.
	 */
	private void showSampleDialogFragment(){
		DialogFragment f = new SampleDialogFragment();
		FragmentTransaction ft = getSupportFragmentManager().beginTransaction();
		if(dualPane){
			ft.replace(R.id.right_column, f, SAMPLE_DIALOG_FRAGMENT);
			ft.commit();
		}else{
			f.show(ft, SAMPLE_DIALOG_FRAGMENT);
		}
	}
}
