package com.example.dialogy;

import android.app.Activity;
import android.os.Bundle;
import android.support.v4.app.DialogFragment;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.ViewGroup;
import android.widget.TextView;

public class SampleDialogFragment extends DialogFragment implements OnClickListener{
	
	private static final String KEY_CLICK_COUNT = "clickCount";
	private int clickCount = 0;
	
	private TextView clickCountDisplay;

	@Override
	public void onAttach(Activity activity){
		super.onAttach(activity);
		log("onAttach");
	}
	
	@Override
	public void onCreate(Bundle savedInstanceState){
		super.onCreate(savedInstanceState);
		
		if(savedInstanceState != null)
				clickCount = savedInstanceState.getInt(KEY_CLICK_COUNT, 0);
		
		log("onCreate");
	}
	
	@Override
	public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState){
		View v = inflater.inflate(R.layout.sample_dialog_fragment, container, false);
		
		v.setOnClickListener(this);
		clickCountDisplay = (TextView)v.findViewById(R.id.click_count_display);
		
		if(getDialog() != null)
			getDialog().setTitle(R.string.click);
		
		displayClickCount();
		
		log("onCreateView");
		
		return v;
	}
	
	@Override
	public void onActivityCreated(Bundle savedInstanceState){
		super.onActivityCreated(savedInstanceState);
		
		// savedInstanceState je ten stejný objekt Bundle jako v onCreate() a onCreateView()
		
		log("onActivityCreated");
	}
	
	@Override
	public void onStart(){
		super.onStart();
		log("onStart");
	}
	
	@Override
	public void onResume(){
		super.onResume();
		log("onResume");
	}
	
	@Override
	public void onPause(){
		super.onPause();
		log("onPause");
	}
	
	@Override
	public void onStop(){
		super.onStop();
		log("onStop");
	}
	
	@Override
	public void onDestroyView(){
		super.onDestroyView();
		log("onDestroyView");
	}
	
	@Override
	public void onSaveInstanceState(Bundle outState) {
		outState.putInt(KEY_CLICK_COUNT, clickCount);

		super.onSaveInstanceState(outState);

		log("onSaveInstanceState");
	}
	
	@Override
	public void onDestroy(){
		super.onDestroy();
		log("onDestroy");
	}
	
	@Override
	public void onDetach(){
		super.onDetach();
		log("onDetach");
	}


	
	private void displayClickCount(){
		clickCountDisplay.setText(String.valueOf(clickCount));
	}
	
	public void onClick(View v) {
		clickCount++;
		displayClickCount();
	}
	
	private void log(String text){
		Log.d("SampleDialogFragment", text);
	}
}
